Skip to contents

Functions for managing the default ellmer Chat object used by dsprrr. When no Chat is explicitly provided to a module or run() call, these functions determine which Chat to use.

Details

The default Chat is resolved in this order:

  1. Explicit options(dsprrr.default_chat = chat_object)

  2. Auto-detection from environment variables:

  3. Error with helpful setup instructions